use colored::*;
use std::io::{self, Write};

pub struct Prompt {
    pub prompt_text: String,
    pub color_enabled: bool,
}

impl Prompt {
    pub fn new(prompt_text: String, color_enabled: bool) -> Self {
        Self {
            prompt_text,
            color_enabled,
        }
    }
    
    pub fn display(&self) -> io::Result<()> {
        if self.color_enabled {
            print!("{}", self.prompt_text.bright_blue().bold());
        } else {
            print!("{}", self.prompt_text);
        }
        io::stdout().flush()
    }
    
    pub fn read_input(&self) -> io::Result<String> {
        let mut input = String::new();
        io::stdin().read_line(&mut input)?;
        Ok(input.trim().to_string())
    }
    
    pub fn success(&self, message: &str) {
        if self.color_enabled {
            println!("{} {}", "✓".green(), message.green());
        } else {
            println!("✓ {}", message);
        }
    }
    
    pub fn error(&self, message: &str) {
        if self.color_enabled {
            eprintln!("{} {}", "✗".red(), message.red());
        } else {
            eprintln!("✗ {}", message);
        }
    }
    
    pub fn info(&self, message: &str) {
        if self.color_enabled {
            println!("{} {}", "ℹ".blue(), message);
        } else {
            println!("ℹ {}", message);
        }
    }
    
    pub fn warning(&self, message: &str) {
        if self.color_enabled {
            println!("{} {}", "⚠".yellow(), message.yellow());
        } else {
            println!("⚠ {}", message);
        }
    }
    
    pub fn code_block(&self, code: &str, language: &str) {
        if self.color_enabled {
            println!("\n{}", format!("```{}", language).bright_black());
            println!("{}", code.cyan());
            println!("{}\n", "```".bright_black());
        } else {
            println!("\n```{}", language);
            println!("{}", code);
            println!("```\n");
        }
    }
}